L10nConfig class
Constructors
Properties
- arbDir ↔ String
-
getter/setter pair
- finalOutputDir → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputClass ↔ String
-
getter/setter pair
- outputDir ↔ String?
-
getter/setter pair
- outputLocalizationFile ↔ String
-
getter/setter pair
- packageImport → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syntheticPackage ↔ bool
-
getter/setter pair
- templateArbFile ↔ String
-
getter/setter pair
- templateFilePath → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
findOrCreateL10nFile(
File l10nFile) → L10nConfig -
getL10nConfig(
[File? file]) → L10nConfig